
JSONL to CONLL
==============

A simple tool to convert JSONL to CONLL

Installation
------------

To install, run

.. code-block:: bash

   pip3 install --user jsonl-to-conll

Usage
-----

Sample Usage
^^^^^^^^^^^^

.. code-block:: bash

   jsonl-to-conll input.jsonl output.conll

Documentation
^^^^^^^^^^^^^

.. code-block:: bash

   usage: jsonl-to-conll [-h] input_filename output_filename
   jsonl-to-conll: error: the following arguments are required: input_filename, output_filename
